@@ -28,7 +28,7 @@ class ModelAdminCrfDashboardMixin(
         initial_data = super().get_changeform_initial_data(request)  # noqa
         try:
             subject_visit = get_subject_visit_model_cls().objects.get(
-                id=request.GET.get(self.model.visit_model_attr())
+                id=request.GET.get(self.model.related_visit_model_attr())
             )
         except ObjectDoesNotExist:
             # TODO: how do we get here? PRN?
